# Changelog

## 0.1.0 (2025-06-08)
Initial release.

- Mostly 1:1 copy of dataframely (including testbench)
- Support for SQL validation
- Support for Rules and Filters with pydiverse.transform syntax
